@@ -2,6 +2,4 @@
 from .comment import CommentAdmin
 from .file import FileAdmin
 from .tag import TagAdmin
-from .follow import FollowAdmin
-from .like import LikeAdmin
-from .save import SaveAdmin
+from .image import ImageAdmin
