@@ -5,6 +5,7 @@ from ..models import File
 
 @admin.register(File)
 class FileAdmin(admin.ModelAdmin):
+    readonly_fields = ['uploaded_by']
     list_display = [
         'slug',
         'created_at',
@@ -14,6 +15,7 @@ class FileAdmin(admin.ModelAdmin):
         'object_id',
         'file',
     ]
+    # autocomplete_fields = ['content_type']
 
     # Ensure current user is assigned as author of post instance.
     def save_model(self, request, obj, form, change):
