@@ -1,7 +1,5 @@
 # arvestust:admin:inlines
-from .like import LikeInline
 from .comment import CommentInline
 from .file import FileInline
-from .follow import FollowInline
 from .tag import TagInline
-from .save import SaveInline
+from .image import ImageInline
