@@ -1,7 +1,5 @@
 # arvestust:forms
 from .file import FileForm
 from .comment import CommentForm
-from .like import LikeForm
 from .tag import TagForm
-from .follow import FollowForm
-from .save import SaveForm
+from .image import ImageForm
