@@ -6,4 +6,4 @@ from .arvestust_record import ArvestustRecordFormMixin
 class CommentForm(ArvestustRecordFormMixin, forms.ModelForm):
     class Meta(ArvestustRecordFormMixin.Meta):
         model = Comment
-        exclude = ArvestustRecordFormMixin.Meta.exclude + ('reports', 'likes')
+        exclude = ArvestustRecordFormMixin.Meta.exclude + ('reports', 'likes', 'user')
