@@ -1,7 +1,6 @@
 # arvestust:models
-from .like import Like
-from .follow import Follow
+from .activity import Activity
 from .comment import Comment
 from .file import File
 from .tag import Tag
-from .save import Save
+from .image import Image
