@@ -1,6 +1,5 @@
 # arvestust:models:managers
 from .comment import CommentManager
 from .file import FileManager
-from .like import LikeManager
+from .activity import ActivityManager
 from .arvestust_file import ArvestustFileManager
-from .save import SaveManager
