@@ -1,7 +1,5 @@
 # arvestust:serializers
-from .like import LikeSerializer
 from .comment import CommentSerializer
 from .file import FileSerializer
 from .tag import TagSerializer
-from .follow import FollowSerializer
-from .save import SaveSerializer
+from .image import ImageSerializer
