@@ -1,8 +1,7 @@
-from django.utils import timezone
 from django.views.generic import ListView
 from django.contrib.auth.mixins import LoginRequiredMixin
 from django.urls import path
-from .routes import routes
+from .urls import urlpatterns
 from ..models import Tag
 
 
@@ -12,17 +11,11 @@ class TagListView(LoginRequiredMixin, ListView):
     template_name = 'tag_list.html'
     paginate_by = 100
 
-    def get_queryset(self):
-        return Tag.objects.filter(
-            author=self.request.user
-        )
-
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['now'] = timezone.now()
         return context
 
 
-routes.append(
+urlpatterns.append(
     path('tags/', TagListView.as_view(), name='tag-list')
 )
