@@ -1,7 +1,5 @@
 # arvestust:viewsets
 from .file import FileViewSet
 from .comment import CommentViewSet
-from .like import LikeViewSet
 from .tag import TagViewSet
-from .follow import FollowViewSet
-from .save import SaveViewSet
+from .image import ImageViewSet
